<?php
include "db_connection.php"; 

// Pagination settings
$limit = 10; 
$page = isset($_GET['page']) ? $_GET['page'] : 1;
$offset = ($page - 1) * $limit;

// Get total number of IB requests
$total_query = "SELECT COUNT(*) AS total FROM ib_requests";
$total_result = mysqli_query($conn, $total_query);
$total_row = mysqli_fetch_assoc($total_result);
$total_records = $total_row['total'];
$total_pages = ceil($total_records / $limit);

// Fetch IB Requests with pagination
$query = "SELECT * FROM ib_requests ORDER BY created_at DESC LIMIT $limit OFFSET $offset";
$result = mysqli_query($conn, $query);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>IB Request List</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
</head>

<body class="bg-gray-50">
    <?php include "header.php"; ?>
    
    <div class="flex h-screen">
        <?php include "side_bar.php"; ?>
        
        <main class="flex-1 p-8">
            <div class="container mx-auto p-6 bg-white rounded-lg shadow-xl">
                <h2 class="text-3xl font-semibold text-gray-700 mb-6">IB Request List</h2>

                <!-- Responsive Table -->
                <div class="overflow-x-auto">
                    <table class="w-full border-collapse bg-white shadow-lg">
                        <thead>
                            <tr class="bg-gray-200 text-gray-600 uppercase text-sm leading-normal">
                                <th class="py-3 px-6 text-left">Request ID</th>
                                <th class="py-3 px-6 text-left">User ID</th>
                                <th class="py-3 px-6 text-left">Name</th>
                                <th class="py-3 px-6 text-left">Email</th>
                                <th class="py-3 px-6 text-left">Status</th>
                                <th class="py-3 px-6 text-left">Actions</th>
                            </tr>
                        </thead>
                        <tbody class="text-gray-700 text-sm">
                            <?php while ($row = mysqli_fetch_assoc($result)) { ?>
                                <tr class="border-b border-gray-200 hover:bg-gray-100">
                                    <td class="py-3 px-6"><?php echo $row['id']; ?></td>
                                    <td class="py-3 px-6"><?php echo $row['user_id']; ?></td>
                                    <td class="py-3 px-6"><?php echo $row['name']; ?></td>
                                    <td class="py-3 px-6"><?php echo $row['email']; ?></td>
                                    <td class="py-3 px-6">
                                        <span id="status-<?php echo $row['id']; ?>" class="px-3 py-1 rounded-full text-white 
                                        <?php echo $row['status'] == 'approved' ? 'bg-green-500' : ($row['status'] == 'rejected' ? 'bg-red-500' : 'bg-yellow-500'); ?>">
                                            <?php echo ucfirst($row['status']); ?>
                                        </span>
                                    </td>
                                    <td class="py-3 px-6">
                                        <?php if ($row['status'] == 'pending') { ?>
                                            <button onclick="updateStatus(<?php echo $row['id']; ?>, 'approved')" 
                                                class="px-3 py-1 bg-green-500 text-white rounded hover:bg-green-600">
                                                Approve
                                            </button>
                                            <button onclick="updateStatus(<?php echo $row['id']; ?>, 'rejected')" 
                                                class="px-3 py-1 bg-red-500 text-white rounded hover:bg-red-600">
                                                Reject
                                            </button>
                                        <?php } else { ?>
                                            <span class="text-gray-500">No Actions</span>
                                        <?php } ?>
                                    </td>
                                </tr>
                            <?php } ?>
                        </tbody>
                    </table>
                </div>

                <!-- Pagination -->
                <div class="flex justify-between items-center mt-6">
                    <a href="?page=<?php echo max(1, $page - 1); ?>" 
                       class="px-4 py-2 bg-gray-300 rounded-lg <?php echo ($page == 1) ? 'opacity-50 cursor-not-allowed' : 'hover:bg-gray-400'; ?>">
                        Previous
                    </a>

                    <span class="text-gray-700">Page <?php echo $page; ?> of <?php echo $total_pages; ?></span>

                    <a href="?page=<?php echo min($total_pages, $page + 1); ?>" 
                       class="px-4 py-2 bg-gray-300 rounded-lg <?php echo ($page == $total_pages) ? 'opacity-50 cursor-not-allowed' : 'hover:bg-gray-400'; ?>">
                        Next
                    </a>
                </div>
            </div>
        </main>
    </div>

    <script>
        function updateStatus(requestId, status) {
            $.ajax({
                url: "update_ib_request.php",
                type: "POST",
                data: { id: requestId, status: status },
                success: function(response) {
                    $("#status-" + requestId).text(status.charAt(0).toUpperCase() + status.slice(1));
                    $("#status-" + requestId).removeClass("bg-yellow-500 bg-green-500 bg-red-500")
                        .addClass(status === 'approved' ? "bg-green-500" : "bg-red-500");

                    // Remove buttons after updating
                    $("button[onclick='updateStatus(" + requestId + ", \"approved\")']").remove();
                    $("button[onclick='updateStatus(" + requestId + ", \"rejected\")']").remove();
                }
            });
        }
    </script>
</body>
</html>
