<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Lot Report</title>
    <link rel="stylesheet" href="style.css">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>
<style>
    body { font-family: Arial, sans-serif; background: #f5f5f5; margin: 0; padding: 0; }
    .container { width: 80%; margin: 50px auto; background: white; padding: 20px; border-radius: 8px; box-shadow: 0 0 10px rgba(0, 0, 0, 0.1); text-align: center; }
    h2 { color: #333; }
    .date-filter, .pagination { display: flex; justify-content: center; gap: 10px; margin-bottom: 20px; }
    input, select, button { padding: 10px; font-size: 16px; }
    button { background: orange; border: none; color: white; cursor: pointer; font-weight: bold; }
    button:hover { background: darkorange; }
    table { width: 100%; border-collapse: collapse; margin-top: 20px; }
    th, td { border: 1px solid #ddd; padding: 10px; text-align: center; }
    th { background: #f4f4f4; }
    canvas { max-width: 400px; margin: 20px auto; display: block; }
    .pagination button { background: #007bff; border: none; color: white; cursor: pointer; padding: 5px 10px; }
    .pagination button:hover { background: #0056b3; }
</style>
<body class="bg-gray-100">
<?php include "header.php";?>
    <div class="flex flex-col md:flex-row h-screen">
        <!-- Sidebar -->
        <?php include "side_bar.php";?>

        <!-- Main Content -->
        <main class="flex-1 p-6 md:ml-64">
    <!-- Top Navigation -->
   <div class="container">
        <h2>Lot Report</h2>

        <div class="date-filter">
            <label for="from">From:</label>
            <input type="date" id="from" required>
            <label for="to">To:</label>
            <input type="date" id="to" required>
            <button id="submit-btn">Submit</button>
        </div>

        <label for="recordsPerPage">Records per page:</label>
        <select id="recordsPerPage">
            <option value="5">5</option>
            <option value="10" selected>10</option>
            <option value="15">15</option>
        </select>

        <canvas id="lotChart"></canvas>

        <div id="lot-data">
            <p>Select a date range and click submit to view data.</p>
        </div>

        <div class="pagination">
            <button id="prev-page">Previous</button>
            <span id="page-number">Page 1</span>
            <button id="next-page">Next</button>
        </div>
    </div>
    </main><?php include "footer.php";?>
    </div>

    <script>
        $(document).ready(function() {
            let currentPage = 1;

            function fetchData() {
                var fromDate = $("#from").val();
                var toDate = $("#to").val();
                var recordsPerPage = $("#recordsPerPage").val();

                if (fromDate && toDate) {
                    $.ajax({
                        url: "fetch_data.php",
                        type: "GET",
                        data: { from: fromDate, to: toDate, page: currentPage, recordsPerPage: recordsPerPage },
                        dataType: "json",
                        success: function(response) {
                            $("#lot-data").html(response.tableData);
                            updateChart(response.chartData);
                            $("#page-number").text("Page " + currentPage);
                            $("#prev-page").prop("disabled", currentPage === 1);
                            $("#next-page").prop("disabled", response.totalPages <= currentPage);
                        },
                        error: function() {
                            alert("Error fetching data.");
                        }
                    });
                } else {
                    alert("Please select both dates!");
                }
            }

            $("#submit-btn").click(function() {
                currentPage = 1;
                fetchData();
            });

            $("#recordsPerPage").change(function() {
                currentPage = 1;
                fetchData();
            });

            $("#prev-page").click(function() {
                if (currentPage > 1) {
                    currentPage--;
                    fetchData();
                }
            });

            $("#next-page").click(function() {
                currentPage++;
                fetchData();
            });
        });

        let lotChart;

        function updateChart(chartData) {
            if (lotChart) {
                lotChart.destroy();
            }

            let ctx = document.getElementById('lotChart').getContext('2d');
            lotChart = new Chart(ctx, {
                type: 'pie',
                data: {
                    labels: chartData.labels,
                    datasets: [{
                        label: 'Lots per Symbol',
                        data: chartData.data,
                        backgroundColor: ['#ff6384', '#36a2eb', '#ffce56', '#4bc0c0', '#9966ff']
                    }]
                }
            });
        }
    </script>

</body>
</html>
