<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>News List</title>
    <script src="https://cdn.tailwindcss.com"></script>
</head>
<body class="bg-gray-100">
<?php include "header.php";?>

<div class="flex flex-col md:flex-row min-h-screen">
    <!-- Sidebar -->
    <?php include "side_bar.php";?>

    <!-- Main Content -->
    <main class="flex-1 p-4 md:p-6">
        <div class="container mx-auto bg-white p-4 md:p-6 shadow-lg rounded-lg">
            <h2 class="text-xl md:text-2xl font-bold mb-4 text-gray-700">News List</h2>
            <button onclick="openAddNewsModal()" class="px-4 py-2 bg-blue-500 text-white rounded-md mb-4 hover:bg-blue-600">Add News</button>

            <div class="overflow-x-auto">
                <table class="min-w-full border-collapse border border-gray-300" id="data-table">
                    <thead class="bg-[#CD7F32] text-white">
                        <tr>
                            <th class="p-2 md:p-3 border text-sm md:text-base">Serial No.</th>
                            <th class="p-2 md:p-3 border text-sm md:text-base">Title</th>
                            <th class="p-2 md:p-3 border text-sm md:text-base">Content</th>
                            <th class="p-2 md:p-3 border text-sm md:text-base">Date</th>
                            <th class="p-2 md:p-3 border text-sm md:text-base">Action</th>
                        </tr>
                    </thead>
                    <tbody id="news-table-body">
                        <tr>
                            <td class="p-2 md:p-3 border text-center">1</td>
                            <td class="p-2 md:p-3 border">Breaking News: Major Event</td>
                            <td class="p-2 md:p-3 border truncate">A major event has taken place today in the city...</td>
                            <td class="p-2 md:p-3 border">2025-02-04</td>
                            <td class="p-2 md:p-3 border flex flex-wrap space-x-1">
                                <button onclick="viewRow(this)" class="px-2 md:px-4 py-1 md:py-2 text-gray-800 bg-[#E8C9A3] rounded-md hover:bg-[#DFC19A]">View</button>
                                <button onclick="editRow(this)" class="px-2 md:px-4 py-1 md:py-2 text-gray-800 bg-[#D6B392] rounded-md hover:bg-[#CBAE88]">Edit</button>
                                <button onclick="deleteRow(this)" class="px-2 md:px-4 py-1 md:py-2 text-gray-800 bg-[#E5A07A] rounded-md hover:bg-[#DA9972]">Delete</button>
                            </td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
    </main>

    <?php include "footer.php";?>
</div>

<!-- Add News Modal -->
<div id="add-news-modal" class="fixed inset-0 flex items-center justify-center bg-gray-900 bg-opacity-50 hidden p-4">
    <div class="bg-white p-6 rounded-lg shadow-lg max-w-md w-full">
        <h3 class="text-lg md:text-xl font-semibold mb-4">Add News</h3>
        <form id="add-news-form">
            <div class="mb-4">
                <label for="title" class="block text-sm font-medium text-gray-700">Title</label>
                <input type="text" id="title" class="w-full p-2 border border-gray-300 rounded-md" required>
            </div>
            <div class="mb-4">
                <label for="content" class="block text-sm font-medium text-gray-700">Content</label>
                <textarea id="content" rows="3" class="w-full p-2 border border-gray-300 rounded-md" required></textarea>
            </div>
            <div class="flex justify-end space-x-2">
                <button type="button" onclick="closeAddNewsModal()" class="px-4 py-2 bg-gray-500 text-white rounded-md hover:bg-gray-600">Cancel</button>
                <button type="submit" class="px-4 py-2 bg-blue-500 text-white rounded-md hover:bg-blue-600">Add News</button>
            </div>
        </form>
    </div>
</div>

<script>
    // Open Add News Modal
    function openAddNewsModal() {
        document.getElementById('add-news-modal').classList.remove('hidden');
    }

    // Close Add News Modal
    function closeAddNewsModal() {
        document.getElementById('add-news-modal').classList.add('hidden');
    }

    // Add News Action (Submit form)
    document.getElementById('add-news-form').addEventListener('submit', function(event) {
        event.preventDefault();

        const title = document.getElementById('title').value;
        const content = document.getElementById('content').value;
        const date = new Date().toISOString().split('T')[0];

        const table = document.getElementById('news-table-body');
        const newRow = table.insertRow();
        
        newRow.innerHTML = `
            <td class="p-2 md:p-3 border text-center">${table.rows.length}</td>
            <td class="p-2 md:p-3 border">${title}</td>
            <td class="p-2 md:p-3 border truncate">${content}</td>
            <td class="p-2 md:p-3 border">${date}</td>
            <td class="p-2 md:p-3 border flex flex-wrap space-x-1">
                <button onclick="viewRow(this)" class="px-2 md:px-4 py-1 md:py-2 text-gray-800 bg-[#E8C9A3] rounded-md hover:bg-[#DFC19A]">View</button>
                <button onclick="editRow(this)" class="px-2 md:px-4 py-1 md:py-2 text-gray-800 bg-[#D6B392] rounded-md hover:bg-[#CBAE88]">Edit</button>
                <button onclick="deleteRow(this)" class="px-2 md:px-4 py-1 md:py-2 text-gray-800 bg-[#E5A07A] rounded-md hover:bg-[#DA9972]">Delete</button>
            </td>
        `;

        closeAddNewsModal();
        document.getElementById('add-news-form').reset();
    });

    // View Action
    function viewRow(button) {
        let row = button.parentNode.parentNode;
        let title = row.cells[1].innerText;
        let content = row.cells[2].innerText;
        let date = row.cells[3].innerText;
        alert(`Title: ${title}\nContent: ${content}\nDate: ${date}`);
    }

    // Edit Action
    function editRow(button) {
        let row = button.parentNode.parentNode;
        let title = prompt("Enter new title:", row.cells[1].innerText);
        let content = prompt("Enter new content:", row.cells[2].innerText);

        if (title && content) {
            row.cells[1].innerText = title;
            row.cells[2].innerText = content;
            alert("News updated successfully!");
        }
    }

    // Delete Action
    function deleteRow(button) {
        let row = button.parentNode.parentNode;
        if (confirm("Are you sure you want to delete this news?")) {
            row.remove();
            alert("News deleted successfully!");
        }
    }
</script>

</body>
</html>
