<?php
if (isset($_GET['status'])) {
    $status = $_GET['status'];
    $messages = [
        'accepted' => 'Follow-up successfully accepted!',
        'rejected' => 'Follow-up successfully rejected!',
        'error'    => 'There was an error processing the follow-up!'
    ];
    if (isset($messages[$status])) {
        echo '<div class="bg-' . ($status == 'accepted' ? 'green' : ($status == 'rejected' ? 'red' : 'yellow')) . 
             '-500 text-white p-2 rounded-lg mb-4">' . $messages[$status] . '</div>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pending Document List</title>
    <script src="https://cdn.tailwindcss.com"></script>
</head>
<body class="bg-gray-100">
    <?php include "header.php";?>
    <div class="flex h-screen">
        <!-- Sidebar -->
        <?php include "side_bar.php";?>

        <!-- Main Content -->
        <main class="flex-1 p-6 md:ml-64">
            <div class="container mx-auto">
                <!-- Search Box -->
                <input type="text" id="search" placeholder="Search..." class="p-2 border border-gray-300 rounded-lg w-1/3 mb-4" oninput="filterTable()">

                <!-- Table Section -->
                <div class="overflow-x-auto bg-white p-6 rounded-lg shadow">
                    <h2 class="text-2xl font-bold text-gray-700 mb-4">Pending Document List</h2>
                    <table class="min-w-full border border-gray-300">
                        <thead class="bg-gray-200">
                            <tr>
                                <th class="p-2 border-b">ID</th>
                                <th class="p-2 border-b">Name</th>
                                <th class="p-2 border-b">Email</th>
                                <th class="p-2 border-b">Country</th>
                                <th class="p-2 border-b">Date</th>
                                <th class="p-2 border-b">Marketing Name</th>
                                <th class="p-2 border-b">Actions</th>
                            </tr>
                        </thead>
                        <tbody id="table-body">
                            <!-- Data will be inserted here via JavaScript -->
                        </tbody>
                    </table>
                </div>
            </div> 
            <br><br><br>
            <?php include "footer.php";?>
        </main>
    </div>

    <!-- JavaScript for Search & Data Population -->
    <script>
        // Sample data
        const documentData = [
            { id: 1, name: "Jane Smith", email: "jane@example.com", country: "Canada", date: "2025-01-28", marketingName: "Jane" },
            { id: 2, name: "John Doe", email: "john@example.com", country: "USA", date: "2025-02-01", marketingName: "John" },
            { id: 3, name: "Alice Brown", email: "alice@example.com", country: "UK", date: "2025-02-05", marketingName: "Alice" }
        ];

        // Populate table with JavaScript data
        function loadTableData() {
            const tableBody = document.getElementById("table-body");
            tableBody.innerHTML = "";

            documentData.forEach(doc => {
                const row = document.createElement("tr");
                row.classList.add("border-b", "hover:bg-gray-100");

                row.innerHTML = `
                    <td class="p-2">${doc.id}</td>
                    <td class="p-2">${doc.name}</td>
                    <td class="p-2">${doc.email}</td>
                    <td class="p-2">${doc.country}</td>
                    <td class="p-2">${doc.date}</td>
                    <td class="p-2 text-red-500">${doc.marketingName}</td>
                    <td class="p-2">
                        <a href="view_pending_document.php?id=${doc.id}" class="text-blue-600 hover:underline">View Details</a>
                    </td>
                `;

                tableBody.appendChild(row);
            });
        }

        // Search Functionality
        function filterTable() {
            const searchInput = document.getElementById("search").value.toLowerCase();
            const tableRows = document.querySelectorAll("#table-body tr");

            tableRows.forEach(row => {
                const text = row.textContent.toLowerCase();
                row.style.display = text.includes(searchInput) ? "" : "none";
            });
        }

        // Load table data on page load
        document.addEventListener("DOMContentLoaded", loadTableData);
    </script>
</body>
</html>
