<?php
// Start session and connect to the database
session_start();
include('db_connection.php'); // Include database connection

// Check if the user is logged in (adjust based on your authentication method)
if (!isset($_SESSION['admin_id'])) {
    header('Location: login.php'); // Redirect to login page if not logged in
    exit();
}

// Fetch admin details from database
$admin_id = $_SESSION['admin_id'];
$sql = "SELECT * FROM admins WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $admin_id);
$stmt->execute();
$result = $stmt->get_result();
$admin = $result->fetch_assoc();

// Handle form submission to update details
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $name = $_POST['name'];
    $email = $_POST['email'];
    $password = $_POST['password'];
    $profile_picture = $admin['profile_picture']; // Default picture

    // Handle profile picture upload
    if (isset($_FILES['profile_picture']) && $_FILES['profile_picture']['error'] == 0) {
        $target_dir = "uploads/";
        $target_file = $target_dir . basename($_FILES["profile_picture"]["name"]);
        move_uploaded_file($_FILES["profile_picture"]["tmp_name"], $target_file);
        $profile_picture = $target_file;
    }

    // Update the admin's details in the database
    $update_sql = "UPDATE admins SET name = ?, email = ?, password = ?, profile_picture = ? WHERE id = ?";
    $update_stmt = $conn->prepare($update_sql);
    $update_stmt->bind_param("ssssi", $name, $email, $password, $profile_picture, $admin_id);
    $update_stmt->execute();

    // Redirect to the profile page after update
    header('Location: profile.php');
    exit();
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Profile</title>
    <script src="https://cdn.tailwindcss.com"></script>
</head>
<body class="bg-gray-100 flex flex-col items-center p-6">

    <div class="w-full max-w-4xl bg-white p-6 rounded-lg shadow-md">
        <h1 class="text-2xl font-semibold text-orange-600 mb-6">Admin Profile</h1>

        <form action="profile.php" method="POST" enctype="multipart/form-data">
            <!-- Admin Profile Image -->
            <div class="flex justify-center mb-4">
                <img src="<?php echo $admin['profile_picture'] ? $admin['profile_picture'] : 'default.jpg'; ?>" alt="Admin Profile" class="w-32 h-32 rounded-full border-2 border-orange-600">
            </div>

            <!-- Profile Picture Upload -->
            <div class="mb-4">
                <label for="profile_picture" class="block text-sm font-medium text-gray-700">Change Profile Picture</label>
                <input type="file" id="profile_picture" name="profile_picture" class="mt-1 p-2 border border-gray-300 rounded-md">
            </div>

            <!-- Name -->
            <div class="mb-4">
                <label for="name" class="block text-sm font-medium text-gray-700">Name</label>
                <input type="text" id="name" name="name" value="<?php echo $admin['name']; ?>" class="mt-1 p-2 border border-gray-300 rounded-md w-full" required>
            </div>

            <!-- Email -->
            <div class="mb-4">
                <label for="email" class="block text-sm font-medium text-gray-700">Email</label>
                <input type="email" id="email" name="email" value="<?php echo $admin['email']; ?>" class="mt-1 p-2 border border-gray-300 rounded-md w-full" required>
            </div>

            <!-- Password -->
            <div class="mb-4">
                <label for="password" class="block text-sm font-medium text-gray-700">Password</label>
                <input type="password" id="password" name="password" value="<?php echo $admin['password']; ?>" class="mt-1 p-2 border border-gray-300 rounded-md w-full" required>
            </div>

            <div class="flex justify-between items-center mt-6">
                <button type="submit" class="bg-orange-600 text-white py-2 px-4 rounded-md">Update Profile</button>
            </div>
        </form>
    </div>

</body>
</html>
