<?php
// Static Users Data
$users = [
    ['username' => 'John Doe', 'email' => 'john@example.com'],
    ['username' => 'Jane Smith', 'email' => 'jane@example.com'],
    ['username' => 'Alice Brown', 'email' => 'alice@example.com'],
    ['username' => 'Bob Johnson', 'email' => 'bob@example.com'],
    ['username' => 'Charlie Davis', 'email' => 'charlie@example.com'],
    ['username' => 'David Wilson', 'email' => 'david@example.com'],
    ['username' => 'Emma Thomas', 'email' => 'emma@example.com'],
    ['username' => 'Frank White', 'email' => 'frank@example.com'],
    ['username' => 'Grace Hall', 'email' => 'grace@example.com'],
    ['username' => 'Henry King', 'email' => 'henry@example.com'],
    ['username' => 'Isla Scott', 'email' => 'isla@example.com'],
    ['username' => 'Jack Evans', 'email' => 'jack@example.com'],
];

// Handle Search Query
$search = isset($_GET['search']) ? strtolower(trim($_GET['search'])) : '';

// Filter Users Based on Search
$filteredUsers = array_filter($users, function ($user) use ($search) {
    return strpos(strtolower($user['username']), $search) !== false || strpos(strtolower($user['email']), $search) !== false;
});

// Handle Pagination
$recordsPerPage = isset($_GET['limit']) ? (int)$_GET['limit'] : 5;
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$totalRecords = count($filteredUsers);
$totalPages = ceil($totalRecords / $recordsPerPage);
$offset = ($page - 1) * $recordsPerPage;

// Get Paginated Results
$paginatedUsers = array_slice($filteredUsers, $offset, $recordsPerPage);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>User List</title>
    <script src="https://cdn.tailwindcss.com"></script>
</head>
 <body class="bg-gray-100">
    <?php include "header.php"; ?>
    
    <div class="flex flex-col md:flex-row min-h-screen">
        <!-- Sidebar -->
        <?php include "side_bar.php"; ?>
        
        <!-- Main Content -->
        <main class="flex-1 p-6 md:ml-64">
                 <div class="container"> 
     <div class="flex justify-between mb-4">
            <!-- Search -->
            <input type="text" id="searchBox" placeholder="Search..." 
                class="p-2 border border-gray-300 rounded-lg w-1/3"
                value="<?php echo htmlspecialchars($search); ?>">

            <!-- Records Per Page -->
            <select id="recordLimit" class="p-2 border border-gray-300 rounded-lg">
                <option value="5" <?php if ($recordsPerPage == 5) echo "selected"; ?>>5</option>
                <option value="10" <?php if ($recordsPerPage == 10) echo "selected"; ?>>10</option>
                <option value="20" <?php if ($recordsPerPage == 20) echo "selected"; ?>>20</option>
            </select>
        </div>

        <!-- User List Table -->
        <h2 class="text-2xl font-bold text-gray-700 mb-4">User List</h2>
        <table class="min-w-full bg-white border border-gray-300 rounded-md">
            <thead>
                <tr>
                    <th class="p-2 border-b">Username</th>
                    <th class="p-2 border-b">Email</th>
                    <th class="p-2 border-b">Actions</th>
                </tr>
            </thead>
            <tbody class="justify-center">
                <?php $i = 0; // Initialize index ?>
                <?php foreach ($paginatedUsers as $user): ?>
                <tr>
                    <td class="p-2"><?php echo $user['username']; ?></td>
                    <td class="p-2"><?php echo $user['email']; ?></td>
                    <td class="p-2">
                        <button class="text-blue-600 editUserBtn" 
                            data-index="<?php echo $i; ?>" 
                            data-username="<?php echo htmlspecialchars($user['username']); ?>" 
                            data-email="<?php echo htmlspecialchars($user['email']); ?>">
                            Edit
                        </button> |
                        <a href="#" class="text-red-600">Delete</a>
                    </td>
                </tr>
                <?php $i++; ?>
                <?php endforeach; ?>
            </tbody>
        </table>

        <!-- Pagination -->
        <div class="flex justify-center mt-4 space-x-2">
            <?php for ($i = 1; $i <= $totalPages; $i++): ?>
                <a href="?page=<?php echo $i; ?>&search=<?php echo urlencode($search); ?>&limit=<?php echo $recordsPerPage; ?>"
                    class="px-3 py-1 border <?php echo ($page == $i) ? 'bg-[#CD7F32] text-white' : 'bg-gray-200'; ?>">
                    <?php echo $i; ?>
                </a>
            <?php endfor; ?>
        </div>
    </div></main>
    <?php include "footer.php";?>
    </div>

    <!-- Edit User Modal (Hidden by Default) -->
    <div id="editModal" class="fixed inset-0 bg-gray-800 bg-opacity-50 flex justify-center items-center hidden">
        <div class="bg-white p-6 rounded-md w-96 shadow-lg">
            <h2 class="text-xl font-bold mb-4">Edit User</h2>
            
            <form id="editForm">
                <input type="hidden" id="editIndex">

                <!-- Username -->
                <label class="block mb-2">Username:</label>
                <input type="text" id="editUsername" class="w-full p-2 border border-gray-300 rounded-lg mb-4">

                <!-- Email -->
                <label class="block mb-2">Email:</label>
                <input type="email" id="editEmail" class="w-full p-2 border border-gray-300 rounded-lg mb-4">

                <!-- Buttons -->
                <div class="flex justify-end space-x-2">
                    <button type="button" id="closeModal" class="px-4 py-2 bg-gray-400 text-white rounded-md">Cancel</button>
                    <button type="submit" class="px-4 py-2 bg-[#CD7F32] text-white rounded-md">Save</button>
                </div>
            </form>
        </div>
    </div>

    <script>
        // Handle Search
        document.getElementById('searchBox').addEventListener('input', function() {
            window.location.href = "?search=" + encodeURIComponent(this.value) + "&limit=" + document.getElementById('recordLimit').value;
        });

        // Handle Records Per Page Change
        document.getElementById('recordLimit').addEventListener('change', function() {
            window.location.href = "?limit=" + this.value + "&search=" + encodeURIComponent(document.getElementById('searchBox').value);
        });

        document.addEventListener('DOMContentLoaded', function () {
            const editModal = document.getElementById('editModal');
            const closeModal = document.getElementById('closeModal');
            const editForm = document.getElementById('editForm');
            const editUsername = document.getElementById('editUsername');
            const editEmail = document.getElementById('editEmail');
            const editIndex = document.getElementById('editIndex');

            document.querySelectorAll('.editUserBtn').forEach((button, index) => {
                button.addEventListener('click', function () {
                    editUsername.value = this.getAttribute('data-username');
                    editEmail.value = this.getAttribute('data-email');
                    editIndex.value = index;
                    editModal.classList.remove('hidden');
                });
            });

            closeModal.addEventListener('click', () => {
                editModal.classList.add('hidden');
            });

            editForm.addEventListener('submit', function (event) {
                event.preventDefault();
                const index = editIndex.value;
                document.querySelectorAll('tbody tr')[index].children[0].textContent = editUsername.value;
                document.querySelectorAll('tbody tr')[index].children[1].textContent = editEmail.value;
                editModal.classList.add('hidden');
            });
        });
    </script>

</body>
</html>
