<?php
// Dummy Data (Simulated dataset)
$deposits = [
    ['id' => 1, 'name' => 'John Doe', 'mt5_id' => 'MT5_1001', 'amount' => 500, 'payment_method' => 'Bank Transfer', 'note' => 'Deposit for trading', 'comment' => 'Verified', 'status' => 'Completed', 'date' => '2025-02-01'],
    ['id' => 2, 'name' => 'Jane Smith', 'mt5_id' => 'MT5_1002', 'amount' => 300, 'payment_method' => 'Crypto', 'note' => 'First deposit', 'comment' => 'Pending review', 'status' => 'Pending', 'date' => '2025-02-02'],
    // Add more dummy records
];

// Get parameters for filtering and pagination
$per_page = isset($_GET['per_page']) ? (int)$_GET['per_page'] : 10;
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$start = ($page - 1) * $per_page;

$date_filter = isset($_GET['date_filter']) ? $_GET['date_filter'] : '';
$search = isset($_GET['search']) ? strtolower($_GET['search']) : '';

// Filter Data
$filtered_deposits = array_filter($deposits, function ($deposit) use ($date_filter, $search) {
    if ($date_filter && $deposit['date'] !== $date_filter) {
        return false;
    }
    if ($search && !stripos($deposit['name'], $search) && !stripos($deposit['mt5_id'], $search) && !stripos($deposit['payment_method'], $search)) {
        return false;
    }
    return true;
});

// Paginate Results
$total_deposits = count($filtered_deposits);
$deposits_to_display = array_slice($filtered_deposits, $start, $per_page);
$total_pages = ceil($total_deposits / $per_page);
?><!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Deposit Report</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-50">
<?php include "header.php"; ?>
<div class="flex flex-col md:flex-row h-screen">
    <?php include "side_bar.php"; ?>

    <main class="flex-1 p-6 md:ml-64">
        <div class="container ">
            <h1 class="text-4xl font-bold text-center mb-6 text-[#CD7F32]">Deposit Report</h1>

            <!-- Filter & Search -->
            <div class="mb-6 flex flex-col md:flex-row items-center justify-between space-y-4 md:space-y-0">
                <!-- Date Filter -->
                <form action="team_deposit_report.php" method="GET" class="flex flex-col md:flex-row space-y-2 md:space-y-0 md:space-x-4 w-full md:w-auto">
                    <label for="date_filter" class="text-[#CD7F32] font-semibold">Date:</label>
                    <input type="date" id="date_filter" name="date_filter" class="px-4 py-2 border border-gray-300 rounded-lg w-full md:w-auto" value="<?php echo $date_filter; ?>">
                    <button type="submit" class="px-4 py-2 bg-[#CD7F32] text-white rounded-lg w-full md:w-auto">Filter</button>
                </form>

                <!-- Search -->
                <form action="team_deposit_report.php" method="GET" class="flex flex-col md:flex-row space-y-2 md:space-y-0 md:space-x-4 w-full md:w-auto">
                    <input type="text" name="search" placeholder="Search Name, MT5 ID, Payment Method" value="<?php echo $search; ?>" class="px-4 py-2 border border-gray-300 rounded-lg w-full md:w-auto" />
                    <button type="submit" class="px-4 py-2 bg-[#CD7F32] text-white rounded-lg w-full md:w-auto">Search</button>
                </form>
            </div>

            <!-- Records Per Page -->
            <div class="mb-6">
                <label for="per_page" class="text-[#CD7F32] font-semibold">Records per page:</label>
                <select id="per_page" name="per_page" class="px-4 py-2 border border-gray-300 rounded-lg" onchange="window.location.href = '?per_page=' + this.value;">
                    <option value="10" <?php echo $per_page == 10 ? 'selected' : ''; ?>>10</option>
                    <option value="25" <?php echo $per_page == 25 ? 'selected' : ''; ?>>25</option>
                    <option value="50" <?php echo $per_page == 50 ? 'selected' : ''; ?>>50</option>
                </select>
            </div>

            <!-- Table Wrapper for Responsiveness -->
            <div class="overflow-x-auto">
                <table class="min-w-full bg-white border border-gray-200 rounded-lg shadow-md">
                    <thead>
                        <tr class="bg-gray-100">
                            <th class="px-4 py-3 border-b text-left text-[#CD7F32]">ID</th>
                            <th class="px-4 py-3 border-b text-left text-[#CD7F32]">Name</th>
                            <th class="px-4 py-3 border-b text-left text-[#CD7F32]">MT5 ID</th>
                            <th class="px-4 py-3 border-b text-left text-[#CD7F32]">Amount</th>
                            <th class="px-4 py-3 border-b text-left text-[#CD7F32]">Payment Method</th>
                            <th class="px-4 py-3 border-b text-left text-[#CD7F32]">Note</th>
                            <th class="px-4 py-3 border-b text-left text-[#CD7F32]">Comment</th>
                            <th class="px-4 py-3 border-b text-left text-[#CD7F32]">Status</th>
                            <th class="px-4 py-3 border-b text-left text-[#CD7F32]">Date</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($deposits_to_display as $deposit): ?>
                            <tr class="hover:bg-gray-50">
                                <td class="px-4 py-4 border-b"><?php echo $deposit['id']; ?></td>
                                <td class="px-4 py-4 border-b"><?php echo $deposit['name']; ?></td>
                                <td class="px-4 py-4 border-b"><?php echo $deposit['mt5_id']; ?></td>
                                <td class="px-4 py-4 border-b"><?php echo '$' . number_format($deposit['amount'], 2); ?></td>
                                <td class="px-4 py-4 border-b"><?php echo $deposit['payment_method']; ?></td>
                                <td class="px-4 py-4 border-b"><?php echo $deposit['note']; ?></td>
                                <td class="px-4 py-4 border-b"><?php echo $deposit['comment']; ?></td>
                                <td class="px-4 py-4 border-b"><?php echo $deposit['status']; ?></td>
                                <td class="px-4 py-4 border-b"><?php echo $deposit['date']; ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <!-- Pagination -->
            <div class="mt-6 flex flex-col md:flex-row justify-between items-center space-y-4 md:space-y-0">
                <span class="text-gray-700">Page <?php echo $page; ?> of <?php echo $total_pages; ?></span>

                <div class="flex space-x-4">
                    <?php if ($page > 1): ?>
                        <a href="?page=<?php echo $page - 1; ?>&per_page=<?php echo $per_page; ?>&search=<?php echo $search; ?>&date_filter=<?php echo $date_filter; ?>" class="px-4 py-2 bg-[#CD7F32] text-white rounded-lg">Previous</a>
                    <?php endif; ?>
                    <?php if ($page < $total_pages): ?>
                        <a href="?page=<?php echo $page + 1; ?>&per_page=<?php echo $per_page; ?>&search=<?php echo $search; ?>&date_filter=<?php echo $date_filter; ?>" class="px-4 py-2 bg-[#CD7F32] text-white rounded-lg">Next</a>
                    <?php endif; ?>
                </div>
            </div>

        </div><br><br><br>
    </main>
    <?php include "footer.php";?>
</div>
</body>
</html>
