<?php
// Dummy Data (Simulated dataset)
$Withdraws = [
    ['id' => 1, 'name' => 'John Doe', 'mt5_id' => 'MT5_1001', 'amount' => 500, 'payment_method' => 'Bank Transfer', 'note' => 'Withdraw for trading', 'comment' => 'Verified', 'status' => 'Completed', 'date' => '2025-02-01'],
    ['id' => 2, 'name' => 'Jane Smith', 'mt5_id' => 'MT5_1002', 'amount' => 300, 'payment_method' => 'Crypto', 'note' => 'First Withdraw', 'comment' => 'Pending review', 'status' => 'Pending', 'date' => '2025-02-02'],
];

// Get parameters for filtering and pagination
$per_page = isset($_GET['per_page']) ? (int)$_GET['per_page'] : 10;
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$start = ($page - 1) * $per_page;

$date_filter = isset($_GET['date_filter']) ? $_GET['date_filter'] : '';
$search = isset($_GET['search']) ? strtolower($_GET['search']) : '';

// Filter Data
$filtered_Withdraws = array_filter($Withdraws, function ($Withdraw) use ($date_filter, $search) {
    if ($date_filter && $Withdraw['date'] !== $date_filter) return false;
    if ($search && !stripos($Withdraw['name'], $search) && !stripos($Withdraw['mt5_id'], $search) && !stripos($Withdraw['payment_method'], $search)) return false;
    return true;
});

// Paginate Results
$total_Withdraws = count($filtered_Withdraws);
$Withdraws_to_display = array_slice($filtered_Withdraws, $start, $per_page);
$total_pages = ceil($total_Withdraws / $per_page);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>IB Withdraw Report</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100">
    <?php include "header.php";?>

    <div class="flex flex-col md:flex-row h-screen">
        <!-- Sidebar -->
        <?php include "side_bar.php";?>

        <!-- Main Content -->
        <main class="flex-1 p-4 md:p-6 md:ml-64">
            <h1 class="text-2xl md:text-3xl font-bold text-center mb-4 text-[#CD7F32]">IB Withdraw Report</h1>

            <!-- Filter & Search -->
            <div class="mb-4 flex flex-col md:flex-row md:justify-between space-y-3 md:space-y-0">
                <form action="#" method="GET" class="flex flex-col sm:flex-row space-y-2 sm:space-y-0 sm:space-x-2">
                    <label class="text-sm text-[#CD7F32] font-semibold">Date:</label>
                    <input type="date" class="px-2 py-1 border border-gray-300 rounded text-sm">
                    <button type="submit" class="px-3 py-1 bg-[#CD7F32] text-white text-sm rounded">Filter</button>
                </form>

                <form action="#" method="GET" class="flex flex-col sm:flex-row space-y-2 sm:space-y-0 sm:space-x-2">
                    <input type="text" placeholder="Search Name, MT5 ID, Payment Method" class="px-2 py-1 border border-gray-300 rounded text-sm" />
                    <button type="submit" class="px-3 py-1 bg-[#CD7F32] text-white text-sm rounded">Search</button>
                </form>
            </div>

            <!-- Records Per Page -->
            <div class="mb-4">
                <label class="text-sm text-[#CD7F32] font-semibold">Records per page:</label>
                <select class="px-2 py-1 border border-gray-300 rounded text-sm">
                    <option value="10">10</option>
                    <option value="25">25</option>
                    <option value="50">50</option>
                </select>
            </div>

            <!-- Withdraw Table -->
            <div class="overflow-x-auto">
                <table class="w-full bg-white border border-gray-200 rounded-lg shadow-md text-sm">
                    <thead>
                        <tr class="bg-gray-100 text-left text-[#CD7F32]">
                            <th class="px-2 py-1 border-b">ID</th>
                            <th class="px-2 py-1 border-b">Name</th>
                            <th class="px-2 py-1 border-b">MT5 ID</th>
                            <th class="px-2 py-1 border-b">Amount</th>
                            <th class="px-2 py-1 border-b">Payment Method</th>
                            <th class="px-2 py-1 border-b">Note</th>
                            <th class="px-2 py-1 border-b">Comment</th>
                            <th class="px-2 py-1 border-b">Status</th>
                            <th class="px-2 py-1 border-b">Date</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr class="hover:bg-gray-50">
                            <td class="px-2 py-1 border-b">1</td>
                            <td class="px-2 py-1 border-b">John Doe</td>
                            <td class="px-2 py-1 border-b">123456</td>
                            <td class="px-2 py-1 border-b">$500.00</td>
                            <td class="px-2 py-1 border-b">Bank Transfer</td>
                            <td class="px-2 py-1 border-b">Urgent</td>
                            <td class="px-2 py-1 border-b">Processed</td>
                            <td class="px-2 py-1 border-b">Completed</td>
                            <td class="px-2 py-1 border-b">2024-02-07</td>
                        </tr>
                        <tr class="hover:bg-gray-50">
                            <td class="px-2 py-1 border-b">2</td>
                            <td class="px-2 py-1 border-b">Alice Smith</td>
                            <td class="px-2 py-1 border-b">789012</td>
                            <td class="px-2 py-1 border-b">$300.00</td>
                            <td class="px-2 py-1 border-b">Crypto</td>
                            <td class="px-2 py-1 border-b">-</td>
                            <td class="px-2 py-1 border-b">Pending</td>
                            <td class="px-2 py-1 border-b">Processing</td>
                            <td class="px-2 py-1 border-b">2024-02-06</td>
                        </tr>
                    </tbody>
                </table>
            </div>

            <!-- Pagination -->
            <div class="mt-4 flex flex-col sm:flex-row justify-between items-center space-y-3 sm:space-y-0">
                <span class="text-xs text-gray-700">Page 1 of 5</span>
                <div class="flex space-x-2">
                    <a href="#" class="px-3 py-1 bg-[#CD7F32] text-white text-xs rounded">Previous</a>
                    <a href="#" class="px-3 py-1 bg-[#CD7F32] text-white text-xs rounded">Next</a>
                </div>
            </div><br><br><br><?php include "footer.php";?>
        </main>
    </div>
</body>
</html>
