<?php
// Dummy Data (Simulated dataset)
$Withdraws = [
    ['id' => 1, 'name' => 'John Doe', 'mt5_id' => 'MT5_1001', 'amount' => 500, 'payment_method' => 'Bank Transfer', 'note' => 'Withdraw for trading', 'comment' => 'Verified', 'status' => 'Completed', 'date' => '2025-02-01'],
    ['id' => 2, 'name' => 'Jane Smith', 'mt5_id' => 'MT5_1002', 'amount' => 300, 'payment_method' => 'Crypto', 'note' => 'First Withdraw', 'comment' => 'Pending review', 'status' => 'Pending', 'date' => '2025-02-02'],
    // Add more dummy records
];

// Get parameters for filtering and pagination
$per_page = isset($_GET['per_page']) ? (int)$_GET['per_page'] : 10;
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$start = ($page - 1) * $per_page;

$date_filter = isset($_GET['date_filter']) ? $_GET['date_filter'] : '';
$search = isset($_GET['search']) ? strtolower($_GET['search']) : '';

// Filter Data
$filtered_Withdraws = array_filter($Withdraws, function ($Withdraw) use ($date_filter, $search) {
    if ($date_filter && $Withdraw['date'] !== $date_filter) {
        return false;
    }
    if ($search && !stripos($Withdraw['name'], $search) && !stripos($Withdraw['mt5_id'], $search) && !stripos($Withdraw['payment_method'], $search)) {
        return false;
    }
    return true;
});

// Paginate Results
$total_Withdraws = count($filtered_Withdraws);
$Withdraws_to_display = array_slice($filtered_Withdraws, $start, $per_page);
$total_pages = ceil($total_Withdraws / $per_page);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>IB Withdraw Report</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-50">
<?php include "header.php"; ?>
<div class="flex h-screen">
    <?php include "side_bar.php"; ?>

    <main class="flex-1 p-8 ml-64">
        <div class="container mx-auto">
            <h1 class="text-4xl font-bold text-center mb-6 text-[#CD7F32]">IB Withdraw Report</h1>

            <!-- Filter & Search -->
            <div class="mb-6 flex justify-between">
                <!-- Date Filter -->
                <form action="team_Withdraw_report.php" method="GET" class="flex space-x-4">
                    <label for="date_filter" class="text-[#CD7F32] font-semibold">Date:</label>
                    <input type="date" id="date_filter" name="date_filter" class="px-4 py-2 border border-gray-300 rounded-lg" value="<?php echo $date_filter; ?>">
                    <button type="submit" class="px-4 py-2 bg-[#CD7F32] text-white rounded-lg">Filter</button>
                </form>

                <!-- Search -->
                <form action="team_Withdraw_report.php" method="GET" class="flex space-x-4">
                    <input type="text" name="search" placeholder="Search Name, MT5 ID, Payment Method" value="<?php echo $search; ?>" class="px-4 py-2 border border-gray-300 rounded-lg" />
                    <button type="submit" class="px-4 py-2 bg-[#CD7F32] text-white rounded-lg">Search</button>
                </form>
            </div>

            <!-- Records Per Page -->
            <div class="mb-6">
                <label for="per_page" class="text-[#CD7F32] font-semibold">Records per page:</label>
                <select id="per_page" name="per_page" class="px-4 py-2 border border-gray-300 rounded-lg" onchange="window.location.href = '?per_page=' + this.value;">
                    <option value="10" <?php echo $per_page == 10 ? 'selected' : ''; ?>>10</option>
                    <option value="25" <?php echo $per_page == 25 ? 'selected' : ''; ?>>25</option>
                    <option value="50" <?php echo $per_page == 50 ? 'selected' : ''; ?>>50</option>
                </select>
            </div>

            <!-- Withdraw Table -->
            <table class="min-w-full bg-white border border-gray-200 rounded-lg shadow-md">
                <thead>
                    <tr>
                        <th class="px-6 py-3 border-b text-left text-[#CD7F32]">ID</th>
                        <th class="px-6 py-3 border-b text-left text-[#CD7F32]">Name</th>
                        <th class="px-6 py-3 border-b text-left text-[#CD7F32]">MT5 ID</th>
                        <th class="px-6 py-3 border-b text-left text-[#CD7F32]">Amount</th>
                        <th class="px-6 py-3 border-b text-left text-[#CD7F32]">Payment Method</th>
                        <th class="px-6 py-3 border-b text-left text-[#CD7F32]">Note</th>
                        <th class="px-6 py-3 border-b text-left text-[#CD7F32]">Comment</th>
                        <th class="px-6 py-3 border-b text-left text-[#CD7F32]">Status</th>
                        <th class="px-6 py-3 border-b text-left text-[#CD7F32]">Date</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($Withdraws_to_display as $Withdraw): ?>
                        <tr>
                            <td class="px-6 py-4 border-b"><?php echo $Withdraw['id']; ?></td>
                            <td class="px-6 py-4 border-b"><?php echo $Withdraw['name']; ?></td>
                            <td class="px-6 py-4 border-b"><?php echo $Withdraw['mt5_id']; ?></td>
                            <td class="px-6 py-4 border-b"><?php echo '$' . number_format($Withdraw['amount'], 2); ?></td>
                            <td class="px-6 py-4 border-b"><?php echo $Withdraw['payment_method']; ?></td>
                            <td class="px-6 py-4 border-b"><?php echo $Withdraw['note']; ?></td>
                            <td class="px-6 py-4 border-b"><?php echo $Withdraw['comment']; ?></td>
                            <td class="px-6 py-4 border-b"><?php echo $Withdraw['status']; ?></td>
                            <td class="px-6 py-4 border-b"><?php echo $Withdraw['date']; ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>

            <!-- Pagination -->
            <div class="mt-6 flex justify-between items-center">
                <div>
                    <span class="text-gray-700">Page <?php echo $page; ?> of <?php echo $total_pages; ?></span>
                </div>
                <div class="flex space-x-4">
                    <?php if ($page > 1): ?>
                        <a href="?page=<?php echo $page - 1; ?>&per_page=<?php echo $per_page; ?>&search=<?php echo $search; ?>&date_filter=<?php echo $date_filter; ?>" class="px-4 py-2 bg-[#CD7F32] text-white rounded-lg">Previous</a>
                    <?php endif; ?>
                    <?php if ($page < $total_pages): ?>
                        <a href="?page=<?php echo $page + 1; ?>&per_page=<?php echo $per_page; ?>&search=<?php echo $search; ?>&date_filter=<?php echo $date_filter; ?>" class="px-4 py-2 bg-[#CD7F32] text-white rounded-lg">Next</a>
                    <?php endif; ?>
                </div>
            </div>

        </div>
    </main>
</div>
</body>
</html>
