<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Money Manager Leaderboard</title>
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.5/css/jquery.dataTables.min.css">
    <style>
        body {
            font-family: 'Poppins', sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f8f9fa;
            color: #333;
        }
        .container {
            max-width: 1200px;
            margin: auto;
            padding: 20px;
            text-align: center;
        }
        .leaderboard {
            display: flex;
            gap: 20px;
            justify-content: center;
            flex-wrap: wrap;
        }
        .leaderboard-card {
            background: linear-gradient(135deg, #ffffff, #dfe6e9);
            padding: 25px;
            border-radius: 20px;
            box-shadow: 0 8px 20px rgba(0, 0, 0, 0.15);
            width: 45%;
            text-align: center;
            transition: all 0.3s ease-in-out;
            position: relative;
        }
        .leaderboard-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 10px 25px rgba(0, 0, 0, 0.2);
        }
        .leaderboard-card img {
            width: 100px;
            height: 100px;
            border-radius: 50%;
            margin-bottom: 10px;
            border: 4px solid #555;
        }
        .returns {
            display: flex;
            justify-content: space-around;
            margin-top: 15px;
            font-weight: bold;
            padding: 10px;
            border-radius: 10px;
            background: rgba(0, 0, 0, 0.05);
        }
        .returns p {
            margin: 5px 0;
        }
        .highlight {
            color: #27ae60;
            font-weight: bold;
        }
        .badge {
            position: absolute;
            top: 10px;
            right: 10px;
            background: #27ae60;
            color: #fff;
            padding: 5px 10px;
            border-radius: 5px;
            font-size: 14px;
        }
        .chart-container {
            width: 100%;
            max-width: 400px;
            margin: 20px auto;
        }
    </style>
</head>
<body class="bg-gray-100">
<?php include "header.php";?>
    <div class="flex flex-col md:flex-row h-screen">
        <!-- Sidebar -->
        <?php include "side_bar.php";?>

        <!-- Main Content -->
        <main class="flex-1 p-6 md:ml-64">
    <!-- Top Navigation -->
    <div class="container">
        <h2>Money Manager Leaderboard</h2>
        <div class="leaderboard">
            <div class="leaderboard-card">
                <span class="badge">#1</span>
                <img src="https://via.placeholder.com/100" alt="Clark Haley">
                <h3>Clark Haley</h3>
                <p>#1000 - 213 days</p>
                <p>Total Profit: <strong>$4652.63</strong></p>
                <p>Min. Investment: <strong>$1400.00</strong></p>
                <p>Total Return: <strong>0.00%</strong></p>
                <div class="chart-container">
                    <canvas id="chart1"></canvas>
                </div>
                <div class="returns">
                    <div>
                        <p>1 Year</p>
                        <p>0.00%</p>
                    </div>
                    <div>
                        <p>6 Months</p>
                        <p>0.00%</p>
                    </div>
                    <div>
                        <p>3 Months</p>
                        <p>0.00%</p>
                    </div>
                </div>
            </div>
        
            <div class="leaderboard-card">
                <span class="badge">#2</span>
                <img src="https://via.placeholder.com/100" alt="Freddy Paulsen">
                <h3>Freddy Paulsen</h3>
                <p>#1002 - 213 days</p>
                <p>Total Profit: <strong>$3355.20</strong></p>
                <p>Min. Investment: <strong>$1000.00</strong></p>
                <p>Total Return: <strong class="highlight">14.59%</strong></p>
                <div class="chart-container">
                    <canvas id="chart2"></canvas>
                </div>
                <div class="returns">
                    <div>
                        <p>1 Year</p>
                        <p class="highlight">14.59%</p>
                    </div>
                    <div>
                        <p>6 Months</p>
                        <p class="highlight">14.59%</p>
                    </div>
                    <div>
                        <p>3 Months</p>
                        <p>0.00%</p>
                    </div>
                </div>
            </div>
        </div>
        <div class="container">
    <h2>Leaderboard Table</h2>
    <table id="leaderboardTable" class="display">
        <thead>
            <tr>
                <th>Rank</th>
                <th>Name</th>
                <th>Account ID</th>
                <th>Total Profit</th>
                <th>Min. Investment</th>
                <th>Total Return</th>
            </tr>
        </thead>
        <tbody>
            <tr>
                <td>#1</td>
                <td>Clark Haley</td>
                <td>#1000</td>
                <td>$4652.63</td>
                <td>$1400.00</td>
                <td>0.00%</td>
            </tr>
            <tr>
                <td>#2</td>
                <td>Freddy Paulsen</td>
                <td>#1002</td>
                <td>$3355.20</td>
                <td>$1000.00</td>
                <td>14.59%</td>
            </tr>
        </tbody>
    </table>
</div>

    </div>
    </main><br><br><br><?php include "footer.php";?>
    </div>
    <script>
        function renderChart(chartId, data, labels) {
            new Chart(document.getElementById(chartId), {
                type: 'bar',
                data: {
                    labels: labels,
                    datasets: [{
                        label: 'Returns (%)',
                        data: data,
                        backgroundColor: ['#27ae60', '#f39c12', '#3498db'],
                        borderWidth: 1
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    scales: {
                        y: { beginAtZero: true }
                    }
                }
            });
        }
        
        renderChart('chart1', [0, 0, 0], ['1 Year', '6 Months', '3 Months']);
        renderChart('chart2', [14.59, 14.59, 0], ['1 Year', '6 Months', '3 Months']);
        $(document).ready(function() {
    $('#leaderboardTable').DataTable();
});

    </script>
</body>
</html>
